--- /usr/local/src/fltk-1.1.4/src/Fl_Scroll.cxx	2003-06-14 21:41:16.000000000 -0700
+++ /usr/local/src/fltk-1.1.4rc2/src/Fl_Scroll.cxx	2003-08-06 15:41:11.000000000 -0700
@@ -27,6 +27,21 @@
 #include <FL/Fl_Scroll.H>
 #include <FL/fl_draw.H>
 
+// ERCO
+static void bgfill(int X, int Y, int W, int H, Fl_Color c, int voff) {
+  fl_color(c);
+  fl_rectf(X,Y,W,H);
+
+  const char *scheme = Fl::scheme();
+  if ( scheme && scheme[0] == 'p' && scheme[1] == 'l' ) {	// quick "plastic" check
+    fl_color(51);	// lighter gray than bg. should probably be based on bgcolor
+    for ( int y=Y; y<=(Y+H); y++ )
+      if ( ( (y+voff) % 4 ) < 2 )
+	fl_line(X, y, (X+W), y);
+    fl_color(c);
+  }
+}
+
 // Clear all but the scrollbars...
 void Fl_Scroll::clear() {
   for (int i=children() - 1; i >= 0; i --) {
@@ -51,8 +66,7 @@
   Fl_Scroll* s = (Fl_Scroll*)v;
   // erase background if there is a boxtype:
   if (s->box()) {
-    fl_color(s->color());
-    fl_rectf(X,Y,W,H);
+    bgfill(X,Y,W,H,s->color(),s->yposition_);	//ERCO
   }
   Fl_Widget*const* a = s->array();
   int R = X; int B = Y; // track bottom & right edge of all children
@@ -75,12 +89,10 @@
   }
   // fill any area to right & bottom of widgets:
   if (R < X+W && B > Y) {
-    fl_color(s->color());
-    fl_rectf(R,Y,X+W-R,B-Y);
+    bgfill(R,Y,X+W-R,B-Y,s->color(),s->yposition_);	//ERCO
   }
   if (B < Y+H) {
-    fl_color(s->color());
-    fl_rectf(X,B,W,Y+H-B);
+    bgfill(X,B,W,Y+H-B,s->color(),s->yposition_);	//ERCO
   }
   fl_pop_clip();
 }
@@ -201,8 +213,8 @@
     draw_child(hscrollbar);
     if (scrollbar.visible() && hscrollbar.visible()) {
       // fill in the little box in the corner
-      fl_color(color());
-      fl_rectf(scrollbar.x(), hscrollbar.y(), scrollbar.w(), hscrollbar.h());
+      bgfill(scrollbar.x(), hscrollbar.y(), scrollbar.w(), 
+             hscrollbar.h(), color(), yposition_);	//ERCO
     }
   } else {
     update_child(scrollbar);
